Module checkpoint

Module checkpoint 

Checkpoint persistence types and traits

Defines the checkpoint saver trait and all checkpoint-related types.

Storage implementations (MemorySaver, SqliteSaver, etc.) are provided by the juncture-checkpoint crate, which implements this trait.

Structs

Checkpoint
Complete checkpoint state
CheckpointFilter
Checkpoint listing filter
CheckpointMetadata
Checkpoint metadata
CheckpointNamespace
Namespace for checkpoint isolation in subgraph execution
CheckpointPendingTask
Pending task in checkpoint
CheckpointTuple
Complete checkpoint tuple with all context
DeltaCounters
Delta tracking counters for a channel
NamespaceSegment
Single namespace segment with node name and invocation UUID
PendingWrite
Pending write from a completed task
PregelTaskInfo
Pregel task information
SerializedSend
Serialized Send operation
StateSnapshot
State snapshot at a specific checkpoint

Enums

CheckpointError
Checkpoint operation errors
CheckpointSource
Source of checkpoint creation
DeltaOp
Delta operation type

Constants

CHECKPOINT_NS_SEPARATOR
Separator used between namespace segments in checkpoint namespace strings.

Traits

CheckpointSaver
Checkpoint persistence interface

Functions

generate_checkpoint_id
Generate a new time-ordered checkpoint ID using UUID v6.